==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/activity/l10n/nl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activiteiten",
    "An error occurred while loading activities" : "Er is een fout opgetreden bij het laden van activiteiten",
    "No activity yet" : "Nog geen activiteit",
    "Load more activities" : "Meer activiteiten laden",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Home" : "Thuis",
    "{name} (invisible)" : "{name} (onzichtbaar)",
    "{name} (restricted)" : "{name} (beperkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Deze stream laat gebeurtenissen zoals toevoegingen, veranderingen en gedeelde bestanden zien",
    "There are no events for this filter" : "Er zijn geen afspraken voor dit filter",
    "Today" : "Vandaag",
    "Yesterday" : "Gisteren",
    "Open file" : "Open bestand",
    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
    "Your feed URL is invalid" : "Je activiteitenkanaal link is ongeldig",
    "Your settings have been updated." : "Je instellingen zijn bijgewerkt",
    "Settings have been updated." : "Instellingen zijn bijgewerkt",
    "Mail" : "E-mail",
    "Stream" : "Doorlopend",
    "All activities" : "Alle activiteiten",
    "By others" : "Door anderen",
    "By you" : "Door jou",
    "\"remote user\"" : "\"externe gebruiker\"",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Er was een activiteit op %s",
    "_and %n more _::_and %n more _" : ["en %n meer ","en %n meer "],
    "Activity notification" : "Activiteitenmelding",
    ", " : ", ",
    "%s and %s" : "%s en %s",
    "Activity" : "Activiteit",
    "Activity feed" : "Activiteitenkanaal",
    "Send activity emails" : "Activiteiten per mail verzenden",
    "Default settings" : "Standaardinstellingen",
    "Configure the default activity settings for new users." : "Configureer de standaard activiteit voor nieuwe gebruikers.",
    "List your own actions in the stream" : "Toon je eigen activiteiten in het overzicht",
    "Notify about your own actions via email" : "Melding van je eigen activiteiten via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Je moet je e-mailadres instellen voordat je meldingen van activiteiten op e-mail kan ontvangen.",
    "Send emails:" : "Verstuur e-mails:",
    "As soon as possible" : "zo snel mogelijk",
    "Hourly" : "Per uur",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Kies voor welke activiteiten je een e-mailnotificatie wenst en welke in de activiteiten app-stream moeten verschijnen.",
    "Choose which activities you want to see in your stream." : "Kies welke activiteiten u in uw stream wilt zien.",
    "Settings" : "Instellingen",
    "Enable RSS feed" : "Zet RSS-kanaal aan",
    "RSS feed" : "RSS kanaal",
    "No more events to load" : "Geen meer activiteiten beschikbaar",
    "Files" : "Bestanden",
    "Error loading activities" : "Fout bij laden het laden van activiteiten",
    "No activities" : "Geen activiteiten",
    "You are receiving this email because the following things happened at %s" : "Je ontvangt deze e-mail, omdat het volgende plaatsvond op %s.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* en %n meer","* en %n meer"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/activity/l10n/nl.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Activiteiten",
    "An error occurred while loading activities" : "Er is een fout opgetreden bij het laden van activiteiten",
    "No activity yet" : "Nog geen activiteit",
    "Load more activities" : "Meer activiteiten laden",
    "Copied!" : "Gekopieerd!",
    "Not supported!" : "Niet ondersteund!",
    "Press ⌘-C to copy." : "Druk op ⌘-C om te kopiëren.",
    "Press Ctrl-C to copy." : "Druk op Ctrl-C om te kopiëren.",
    "Home" : "Thuis",
    "{name} (invisible)" : "{name} (onzichtbaar)",
    "{name} (restricted)" : "{name} (beperkt)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Deze stream laat gebeurtenissen zoals toevoegingen, veranderingen en gedeelde bestanden zien",
    "There are no events for this filter" : "Er zijn geen afspraken voor dit filter",
    "Today" : "Vandaag",
    "Yesterday" : "Gisteren",
    "Open file" : "Open bestand",
    "Personal activity feed for %s" : "Persoonlijk activiteitenkanaal voor %s",
    "Your feed URL is invalid" : "Je activiteitenkanaal link is ongeldig",
    "Your settings have been updated." : "Je instellingen zijn bijgewerkt",
    "Settings have been updated." : "Instellingen zijn bijgewerkt",
    "Mail" : "E-mail",
    "Stream" : "Doorlopend",
    "All activities" : "Alle activiteiten",
    "By others" : "Door anderen",
    "By you" : "Door jou",
    "\"remote user\"" : "\"externe gebruiker\"",
    "Hello %s" : "Hallo %s",
    "Hello %s," : "Hallo %s,",
    "There was some activity at %s" : "Er was een activiteit op %s",
    "_and %n more _::_and %n more _" : ["en %n meer ","en %n meer "],
    "Activity notification" : "Activiteitenmelding",
    ", " : ", ",
    "%s and %s" : "%s en %s",
    "Activity" : "Activiteit",
    "Activity feed" : "Activiteitenkanaal",
    "Send activity emails" : "Activiteiten per mail verzenden",
    "Default settings" : "Standaardinstellingen",
    "Configure the default activity settings for new users." : "Configureer de standaard activiteit voor nieuwe gebruikers.",
    "List your own actions in the stream" : "Toon je eigen activiteiten in het overzicht",
    "Notify about your own actions via email" : "Melding van je eigen activiteiten via e-mail",
    "You need to set up your email address before you can receive notification emails." : "Je moet je e-mailadres instellen voordat je meldingen van activiteiten op e-mail kan ontvangen.",
    "Send emails:" : "Verstuur e-mails:",
    "As soon as possible" : "zo snel mogelijk",
    "Hourly" : "Per uur",
    "Daily" : "Dagelijks",
    "Weekly" : "Wekelijks",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Kies voor welke activiteiten je een e-mailnotificatie wenst en welke in de activiteiten app-stream moeten verschijnen.",
    "Choose which activities you want to see in your stream." : "Kies welke activiteiten je in je stream wilt zien.",
    "Settings" : "Instellingen",
    "Enable RSS feed" : "Zet RSS-kanaal aan",
    "RSS feed" : "RSS kanaal",
    "No more events to load" : "Geen meer activiteiten beschikbaar",
    "Files" : "Bestanden",
    "Error loading activities" : "Fout bij laden het laden van activiteiten",
    "No activities" : "Geen activiteiten",
    "You are receiving this email because the following things happened at %s" : "Je ontvangt deze e-mail, omdat het volgende plaatsvond op %s.",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* en %n meer","* en %n meer"]
},
"nplurals=2; plural=(n != 1);");
